@@ -77,6 +77,9 @@ const char* AppConfig::m_SynergySettingsName[] = {
         "serverHostname",
         "tlsCertPath",
         "tlsKeyLength",
+        "preventSleep",
+        "languageSync",
+        "invertScrollDirection"
 };
 
 static const char* logLevelNames[] =
@@ -239,6 +242,9 @@ void AppConfig::loadSettings()
     m_UseInternalConfig         = loadSetting(kUseInternalConfig, false).toBool();
     m_ClientGroupChecked        = loadSetting(kGroupClientCheck, false).toBool();
     m_ServerHostname            = loadSetting(kServerHostname).toString();
+    m_PreventSleep              = loadSetting(kPreventSleep, false).toBool();
+    m_LanguageSync              = loadSetting(kLanguageSync, false).toBool();
+    m_InvertScrollDirection     = loadSetting(kInvertScrollDirection, false).toBool();
 
     //only change the serial key if the settings being loaded contains a key
     bool updateSerial = ConfigWriter::make()
@@ -299,6 +305,9 @@ void AppConfig::saveSettings()
         setSetting(kUseInternalConfig, m_UseInternalConfig);
         setSetting(kGroupClientCheck, m_ClientGroupChecked);
         setSetting(kServerHostname, m_ServerHostname);
+        setSetting(kPreventSleep, m_PreventSleep);
+        setSetting(kLanguageSync, m_LanguageSync);
+        setSetting(kInvertScrollDirection, m_InvertScrollDirection);
     }
 
     m_unsavedChanges = false;
@@ -448,12 +457,26 @@ void AppConfig::setMinimizeToTray(bool newValue) {
     setSettingModified(m_MinimizeToTray, newValue);
 }
 
+bool AppConfig::getInvertScrollDirection() const {
+    return m_InvertScrollDirection;
+}
+
 bool AppConfig::getLanguageSync() const { return m_LanguageSync; }
 
+void AppConfig::setInvertScrollDirection(bool newValue) {
+    setSettingModified(m_InvertScrollDirection, newValue);
+}
+
 void AppConfig::setLanguageSync(bool newValue) {
     setSettingModified(m_LanguageSync, newValue);
 }
 
+bool AppConfig::getPreventSleep() const { return m_PreventSleep; }
+
+void AppConfig::setPreventSleep(bool newValue) {
+    setSettingModified(m_PreventSleep, newValue);
+}
+
 bool AppConfig::getMinimizeToTray() { return m_MinimizeToTray; }
 
 QString AppConfig::settingName(AppConfig::Setting name) {
