@@ -76,6 +76,31 @@ bool ServerConfig::save(const QString& fileName) const
     return true;
 }
 
+bool ServerConfig::operator==(const ServerConfig& sc) const
+{
+    return m_Screens                == sc.m_Screens                &&
+           m_NumColumns             == sc.m_NumColumns             &&
+           m_NumRows                == sc.m_NumRows                &&
+           m_HasHeartbeat           == sc.m_HasHeartbeat           &&
+           m_Heartbeat              == sc.m_Heartbeat              &&
+           m_RelativeMouseMoves     == sc.m_RelativeMouseMoves     &&
+           m_Win32KeepForeground    == sc.m_Win32KeepForeground    &&
+           m_HasSwitchDelay         == sc.m_HasSwitchDelay         &&
+           m_SwitchDelay            == sc.m_SwitchDelay            &&
+           m_HasSwitchDoubleTap     == sc.m_HasSwitchDoubleTap     &&
+           m_SwitchDoubleTap        == sc.m_SwitchDoubleTap        &&
+           m_SwitchCornerSize       == sc.m_SwitchCornerSize       &&
+           m_SwitchCorners          == sc.m_SwitchCorners          &&
+           m_Hotkeys                == sc.m_Hotkeys                &&
+           m_pAppConfig             == sc.m_pAppConfig             &&
+           m_IgnoreAutoConfigClient == sc.m_IgnoreAutoConfigClient &&
+           m_EnableDragAndDrop      == sc.m_EnableDragAndDrop      &&
+           m_DisableLockToScreen    == sc.m_DisableLockToScreen    &&
+           m_ClipboardSharing       == sc.m_ClipboardSharing       &&
+           m_ClipboardSharingSize   == sc.m_ClipboardSharingSize   &&
+           m_pMainWindow            == sc.m_pMainWindow;
+}
+
 void ServerConfig::save(QFile& file) const
 {
     QTextStream outStream(&file);
@@ -86,6 +111,7 @@ void ServerConfig::init()
 {
     switchCorners().clear();
     screens().clear();
+    hotkeys().clear();
 
     // m_NumSwitchCorners is used as a fixed size array. See Screen::init()
     for (int i = 0; i < NumSwitchCorners; i++)
@@ -108,7 +134,6 @@ void ServerConfig::saveSettings()
     settings().setValue("hasHeartbeat", hasHeartbeat());
     settings().setValue("heartbeat", heartbeat());
     settings().setValue("relativeMouseMoves", relativeMouseMoves());
-    settings().setValue("screenSaverSync", screenSaverSync());
     settings().setValue("win32KeepForeground", win32KeepForeground());
     settings().setValue("hasSwitchDelay", hasSwitchDelay());
     settings().setValue("switchDelay", switchDelay());
@@ -163,7 +188,6 @@ void ServerConfig::loadSettings()
     haveHeartbeat(settings().value("hasHeartbeat", false).toBool());
     setHeartbeat(settings().value("heartbeat", 5000).toInt());
     setRelativeMouseMoves(settings().value("relativeMouseMoves", false).toBool());
-    setScreenSaverSync(settings().value("screenSaverSync", true).toBool());
     setWin32KeepForeground(settings().value("win32KeepForeground", false).toBool());
     haveSwitchDelay(settings().value("hasSwitchDelay", false).toBool());
     setSwitchDelay(settings().value("switchDelay", 250).toInt());
@@ -173,9 +197,9 @@ void ServerConfig::loadSettings()
     setIgnoreAutoConfigClient(settings().value("ignoreAutoConfigClient").toBool());
     setDisableLockToScreen(settings().value("disableLockToScreen", false).toBool());
     setEnableDragAndDrop(settings().value("enableDragAndDrop", true).toBool());
-	setClipboardSharing(settings().value("clipboardSharing", true).toBool());
 	setClipboardSharingSize(settings().value("clipboardSharingSize",
 						(int) ServerConfig::defaultClipboardSharingSize()).toULongLong());
+    setClipboardSharing(settings().value("clipboardSharing", true).toBool());
 
     readSettings(settings(), switchCorners(), "switchCorner", false, NumSwitchCorners);
 
@@ -263,7 +287,6 @@ QTextStream& operator<<(QTextStream& outStream, const ServerConfig& config)
         outStream << "\t" << "heartbeat = " << config.heartbeat() << endl;
 
     outStream << "\t" << "relativeMouseMoves = " << (config.relativeMouseMoves() ? "true" : "false") << endl;
-    outStream << "\t" << "screenSaverSync = " << (config.screenSaverSync() ? "true" : "false") << endl;
     outStream << "\t" << "win32KeepForeground = " << (config.win32KeepForeground() ? "true" : "false") << endl;
     outStream << "\t" << "disableLockToScreen = " << (config.disableLockToScreen() ? "true" : "false") << endl;
     outStream << "\t" << "clipboardSharing = " << (config.clipboardSharing() ? "true" : "false") << endl;
