@@ -16,6 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "SettingsDialog.h"
+#include "validators/ScreenNameValidator.h"
 
 #include "CoreInterface.h"
 #include "SynergyLocale.h"
@@ -51,16 +52,27 @@ SettingsDialog::SettingsDialog(QWidget* parent, AppConfig& config) :
     buttonBox->button(QDialogButtonBox::Save)->setEnabled(false);
     enableControls(appConfig().isWritable());
 
-    connect(m_pLineEditLogFilename,     SIGNAL(textChanged(const QString&)), this, SLOT(onChange()));
-    connect(m_pComboLogLevel,           SIGNAL(currentIndexChanged(int)),    this, SLOT(onChange()));
-    connect(m_pLineEditCertificatePath, SIGNAL(textChanged(const QString&)), this, SLOT(onChange()));
-    connect(m_pCheckBoxAutoConfig,      SIGNAL(clicked()),                   this, SLOT(onChange()));
-    connect(m_pCheckBoxMinimizeToTray,  SIGNAL(clicked()),                   this, SLOT(onChange()));
-    connect(m_pCheckBoxAutoHide,        SIGNAL(clicked()),                   this, SLOT(onChange()));
-    connect(m_pLineEditInterface,       SIGNAL(textEdited(const QString&)),  this, SLOT(onChange()));
-    connect(m_pSpinBoxPort,             SIGNAL(valueChanged(int)),           this, SLOT(onChange()));
-    connect(m_pLineEditScreenName,      SIGNAL(textEdited(const QString&)),  this, SLOT(onChange()));
-    connect(m_pComboElevate,            SIGNAL(currentIndexChanged(int)),    this, SLOT(onChange()));
+    m_pCheckBoxLanguageSync->setVisible(m_pMainWindow->synergyType() == MainWindow::synergyClient);
+    m_pCheckBoxScrollDirection->setVisible(m_pMainWindow->synergyType() == MainWindow::synergyClient);
+
+    const auto& serveConfig = m_pMainWindow->serverConfig();
+    m_pLineEditScreenName->setValidator(new validators::ScreenNameValidator(m_pLineEditScreenName, m_pLabelNameError, (&serveConfig.screens())));
+
+    connect(m_pLineEditLogFilename,     SIGNAL(textChanged(QString)),     this, SLOT(onChange()));
+    connect(m_pComboLogLevel,           SIGNAL(currentIndexChanged(int)), this, SLOT(onChange()));
+    connect(m_pLineEditCertificatePath, SIGNAL(textChanged(QString)),     this, SLOT(onChange()));
+    connect(m_pCheckBoxAutoConfig,      SIGNAL(clicked()),                this, SLOT(onChange()));
+    connect(m_pCheckBoxMinimizeToTray,  SIGNAL(clicked()),                this, SLOT(onChange()));
+    connect(m_pCheckBoxAutoHide,        SIGNAL(clicked()),                this, SLOT(onChange()));
+    connect(m_pCheckBoxPreventSleep,    SIGNAL(clicked()),                this, SLOT(onChange()));
+    connect(m_pLineEditInterface,       SIGNAL(textEdited(QString)),      this, SLOT(onChange()));
+    connect(m_pSpinBoxPort,             SIGNAL(valueChanged(int)),        this, SLOT(onChange()));
+    connect(m_pLineEditScreenName,      SIGNAL(textEdited(QString)),      this, SLOT(onChange()));
+    connect(m_pComboElevate,            SIGNAL(currentIndexChanged(int)), this, SLOT(onChange()));
+    connect(m_pCheckBoxLanguageSync,    SIGNAL(clicked()),                this, SLOT(onChange()));
+    connect(m_pCheckBoxScrollDirection, SIGNAL(clicked()),                this, SLOT(onChange()));
+
+    adjustSize();
 }
 
 void SettingsDialog::accept()
@@ -75,11 +87,14 @@ void SettingsDialog::accept()
    appConfig().setLanguage(m_pComboLanguage->itemData(m_pComboLanguage->currentIndex()).toString());
    appConfig().setElevateMode(static_cast<ElevateMode>(m_pComboElevate->currentIndex()));
    appConfig().setAutoHide(m_pCheckBoxAutoHide->isChecked());
+   appConfig().setPreventSleep(m_pCheckBoxPreventSleep->isChecked());
    appConfig().setAutoConfig(m_pCheckBoxAutoConfig->isChecked());
    appConfig().setMinimizeToTray(m_pCheckBoxMinimizeToTray->isChecked());
    appConfig().setTLSCertPath(m_pLineEditCertificatePath->text());
    appConfig().setTLSKeyLength(m_pComboBoxKeyLength->currentText());
    appConfig().setCryptoEnabled(m_pCheckBoxEnableCrypto->isChecked());
+   appConfig().setLanguageSync(m_pCheckBoxLanguageSync->isChecked());
+   appConfig().setInvertScrollDirection(m_pCheckBoxScrollDirection->isChecked());
 
    appConfig().saveSettings();
    QDialog::accept();
@@ -133,9 +148,12 @@ void SettingsDialog::loadFromConfig() {
     m_pLineEditLogFilename->setText(appConfig().logFilename());
     setIndexFromItemData(m_pComboLanguage, appConfig().language());
     m_pCheckBoxAutoHide->setChecked(appConfig().getAutoHide());
+    m_pCheckBoxPreventSleep->setChecked(appConfig().getPreventSleep());
     m_pCheckBoxMinimizeToTray->setChecked(appConfig().getMinimizeToTray());
     m_pLineEditCertificatePath->setText(appConfig().getTLSCertPath());
     m_pCheckBoxEnableCrypto->setChecked(m_appConfig.getCryptoEnabled());
+    m_pCheckBoxLanguageSync->setChecked(m_appConfig.getLanguageSync());
+    m_pCheckBoxScrollDirection->setChecked(m_appConfig.getInvertScrollDirection());
 
     //If the tls file exists test its key length
     if (QFile(appConfig().getTLSCertPath()).exists()) {
@@ -170,19 +188,6 @@ void SettingsDialog::loadFromConfig() {
 #endif
 
     m_pCheckBoxEnableCrypto->setChecked(m_appConfig.getCryptoEnabled());
-    m_pGroupBoxTLS->setVisible(m_appConfig.getCryptoEnabled());
-
-#ifdef SYNERGY_ENTERPRISE
-
-    m_pCheckBoxEnableCrypto->setEnabled(true);
-     m_pLabelProUpgrade->hide();
-
-#else
-
-    m_pCheckBoxEnableCrypto->setEnabled(m_appConfig.isCryptoAvailable());
-    m_pLabelProUpgrade->setVisible(!m_appConfig.isCryptoAvailable());
-
-#endif
 
 #if !defined(SYNERGY_ENTERPRISE) && defined(SYNERGY_AUTOCONFIG)
     m_pCheckBoxAutoConfig->setChecked(appConfig().autoConfig());
@@ -191,7 +196,6 @@ void SettingsDialog::loadFromConfig() {
     m_pLabelInstallBonjour->hide();
 #endif
 
-    adjustSize();
 }
 
 void SettingsDialog::allowAutoConfig()
@@ -205,6 +209,7 @@ void SettingsDialog::on_m_pCheckBoxLogToFile_stateChanged(int i)
 {
     bool checked = i == 2;
 
+    m_pLabelLogPath->setEnabled(checked);
     m_pLineEditLogFilename->setEnabled(checked);
     m_pButtonBrowseLog->setEnabled(checked);
     buttonBox->button(QDialogButtonBox::Save)->setEnabled(isModified());
@@ -230,15 +235,33 @@ void SettingsDialog::on_m_pComboLanguage_currentIndexChanged(int index)
     buttonBox->button(QDialogButtonBox::Save)->setEnabled(isModified());
 }
 
-void SettingsDialog::on_m_pCheckBoxEnableCrypto_toggled(bool checked)
+void SettingsDialog::on_m_pCheckBoxEnableCrypto_clicked(bool checked)
 {
-    buttonBox->button(QDialogButtonBox::Save)->setEnabled(isModified());
-    if (checked) {
-        verticalSpacer_4->changeSize(10, 10, QSizePolicy::Minimum);
-    } else {
-        verticalSpacer_4->changeSize(10, 0, QSizePolicy::Ignored);
+    if (appConfig().isCryptoAvailable())
+    {
+        m_pLabelKeyLength->setEnabled(checked);
+        m_pComboBoxKeyLength->setEnabled(checked);
+        m_pLabelCertificate->setEnabled(checked);
+        m_pLineEditCertificatePath->setEnabled(checked);
+        m_pPushButtonBrowseCert->setEnabled(checked);
+        m_pPushButtonRegenCert->setEnabled(checked);
+
+        buttonBox->button(QDialogButtonBox::Save)->setEnabled(isModified());
+    }
+    else
+    {
+        m_pCheckBoxEnableCrypto->setChecked(false);
+
+        QMessageBox message(this);
+        message.addButton(QObject::tr("Close"), QMessageBox::RejectRole);
+        message.addButton(QObject::tr("Upgrade"), QMessageBox::AcceptRole);
+        message.setText(QObject::tr("TLS encryption is Synergy Pro feature.\nPlease upgrade if this is important to you"));
+
+        if (message.exec() == QMessageBox::Accepted)
+        {
+            QDesktopServices::openUrl(QUrl(QCoreApplication::organizationDomain() + "synergy/purchase/upgrade"));
+        }
     }
-    adjustSize();
 }
 
 void SettingsDialog::on_m_pLabelInstallBonjour_linkActivated(const QString&)
@@ -284,10 +307,9 @@ void SettingsDialog::updateRegenButton() {
     // Disable the Regenerate cert button if the key length is different to saved
     auto keyChanged = appConfig().getTLSKeyLength() != m_pComboBoxKeyLength->currentText();
     auto pathChanged = appConfig().getTLSCertPath() != m_pLineEditCertificatePath->text();
-    auto cryptoChanged = appConfig().getCryptoEnabled() != m_pCheckBoxEnableCrypto->isChecked();
     //NOR the above bools, if any have changed regen should be disabled as it will be done on save
-    auto nor = !(keyChanged || pathChanged || cryptoChanged);
-    m_pPushButtonRegenCert->setEnabled(nor);
+    auto nor = !(keyChanged || pathChanged);
+    m_pPushButtonRegenCert->setEnabled(nor && m_pCheckBoxEnableCrypto->isChecked());
 }
 
 void SettingsDialog::on_m_pPushButtonRegenCert_clicked() {
@@ -305,8 +327,9 @@ void SettingsDialog::updateKeyLengthOnFile(const QString &path) {
 
 bool SettingsDialog::isModified()
 {
-   return (
-      appConfig().screenName()           != m_pLineEditScreenName->text()
+   return (!m_pLineEditScreenName->text().isEmpty() &&
+      m_pLabelNameError->text().isEmpty() &&
+      (appConfig().screenName()          != m_pLineEditScreenName->text()
       || appConfig().port()              != m_pSpinBoxPort->value()
       || appConfig().networkInterface()  != m_pLineEditInterface->text()
       || appConfig().logLevel()          != m_pComboLogLevel->currentIndex()
@@ -315,11 +338,15 @@ bool SettingsDialog::isModified()
       || appConfig().language()          != m_pComboLanguage->itemData(m_pComboLanguage->currentIndex()).toString()
       || appConfig().elevateMode()       != static_cast<ElevateMode>(m_pComboElevate->currentIndex())
       || appConfig().getAutoHide()       != m_pCheckBoxAutoHide->isChecked()
+      || appConfig().getPreventSleep()   != m_pCheckBoxPreventSleep->isChecked()
       || appConfig().autoConfig()        != m_pCheckBoxAutoConfig->isChecked()
       || appConfig().getMinimizeToTray() != m_pCheckBoxMinimizeToTray->isChecked()
       || appConfig().getTLSCertPath()    != m_pLineEditCertificatePath->text()
       || appConfig().getTLSKeyLength()   != m_pComboBoxKeyLength->currentText()
       || appConfig().getCryptoEnabled()  != m_pCheckBoxEnableCrypto->isChecked()
+      || appConfig().isSystemScoped()    != m_isSystemAtStart
+      || appConfig().getLanguageSync()   != m_pCheckBoxLanguageSync->isChecked()
+      || appConfig().getInvertScrollDirection() != m_pCheckBoxScrollDirection->isChecked())
    );
 }
 
@@ -332,26 +359,39 @@ void SettingsDialog::enableControls(bool enable) {
     m_pComboLanguage->setEnabled(enable);
     m_pComboElevate->setEnabled(enable);
     m_pCheckBoxAutoHide->setEnabled(enable);
+    m_pCheckBoxPreventSleep->setEnabled(enable);
     m_pCheckBoxAutoConfig->setEnabled(enable);
     m_pCheckBoxMinimizeToTray->setEnabled(enable);
     m_pLineEditCertificatePath->setEnabled(enable);
     m_pComboBoxKeyLength->setEnabled(enable);
     m_pPushButtonBrowseCert->setEnabled(enable);
+    m_pCheckBoxEnableCrypto->setEnabled(enable);
     m_labelAdminRightsMessage->setVisible(!enable);
+    m_pCheckBoxLanguageSync->setEnabled(enable);
+    m_pCheckBoxScrollDirection->setEnabled(enable);
 
     if (enable) {
+        m_pLabelLogPath->setEnabled(m_pCheckBoxLogToFile->isChecked());
         m_pLineEditLogFilename->setEnabled(m_pCheckBoxLogToFile->isChecked());
         m_pButtonBrowseLog->setEnabled(m_pCheckBoxLogToFile->isChecked());
-        m_pCheckBoxEnableCrypto->setEnabled(m_appConfig.isCryptoAvailable());
+        m_pLabelKeyLength->setEnabled(m_pCheckBoxEnableCrypto->isChecked());
+        m_pComboBoxKeyLength->setEnabled(m_pCheckBoxEnableCrypto->isChecked());
+        m_pLabelCertificate->setEnabled(m_pCheckBoxEnableCrypto->isChecked());
+        m_pLineEditCertificatePath->setEnabled(m_pCheckBoxEnableCrypto->isChecked());
+        m_pPushButtonBrowseCert->setEnabled(m_pCheckBoxEnableCrypto->isChecked());
         updateRegenButton();
     }
     else {
+        m_pLabelLogPath->setEnabled(enable);
         m_pLineEditLogFilename->setEnabled(enable);
         m_pButtonBrowseLog->setEnabled(enable);
-        m_pCheckBoxEnableCrypto->setEnabled(enable);
+        m_pLabelKeyLength->setEnabled(enable);
+        m_pComboBoxKeyLength->setEnabled(enable);
+        m_pLabelCertificate->setEnabled(enable);
+        m_pLineEditCertificatePath->setEnabled(enable);
+        m_pPushButtonBrowseCert->setEnabled(enable);
         m_pPushButtonRegenCert->setEnabled(enable);
     }
-
 }
 
 void SettingsDialog::onChange()
