@@ -23,6 +23,7 @@
 #include "mt/Lock.h"
 #include "arch/XArch.h"
 #include "base/Log.h"
+#include "base/Path.h"
 
 #include <openssl/ssl.h>
 #include <openssl/err.h>
@@ -333,7 +334,7 @@ SecureSocket::loadCertificates(String& filename)
         return false;
     }
     else {
-        std::ifstream file(filename.c_str());
+        std::ifstream file(synergy::filesystem::path(filename));
         bool exist = file.good();
         file.close();
 
@@ -706,18 +707,21 @@ SecureSocket::verifyCertFingerprint()
     // check if this fingerprint exist
     String fileLine;
     std::ifstream file;
-    file.open(trustedServersFilename.c_str());
+    file.open(synergy::filesystem::path(trustedServersFilename));
 
     bool isValid = false;
-    while (!file.eof() && file.is_open()) {
-        getline(file,fileLine);
-        if (!fileLine.empty()) {
-            if (fileLine.compare(fingerprint) == 0) {
+    if (file.is_open()) {
+        while (!file.eof()) {
+            getline(file,fileLine);
+            if (!fileLine.empty() && !fileLine.compare(fingerprint)) {
                 isValid = true;
                 break;
             }
         }
     }
+    else {
+        LOG((CLOG_ERR "Fail to open trusted fingerprints file: %s", trustedServersFilename.c_str()));
+    }
 
     file.close();
     return isValid;
