@@ -101,16 +101,22 @@ ArgParser::parseClientArgs(lib::synergy::ClientArgs& args, int argc, const char*
             ++i;
             continue;
         }
-        else if (isArg(i, argc, argv, NULL, "--camp")) {
+        else if (isArg(i, argc, argv, nullptr, "--camp")) {
             // ignore -- included for backwards compatibility
         }
-        else if (isArg(i, argc, argv, NULL, "--no-camp")) {
+        else if (isArg(i, argc, argv, nullptr, "--no-camp")) {
             // ignore -- included for backwards compatibility
         }
-        else if (isArg(i, argc, argv, NULL, "--yscroll", 1)) {
+        else if (isArg(i, argc, argv, nullptr, "--yscroll", 1)) {
             // define scroll
             args.m_yscroll = atoi(argv[++i]);
         }
+        else if (isArg(i, argc, argv, nullptr, "--sync-language")) {
+            args.m_enableLangSync = true;
+        }
+        else if (isArg(i, argc, argv, nullptr, "--invert-scroll")) {
+            args.m_clientScrollDirection = lib::synergy::ClientScrollDirection::INVERT_SERVER;
+        }
         else {
             if (i + 1 == argc) {
                 args.m_synergyAddress = argv[i];
@@ -141,14 +147,14 @@ bool
 ArgParser::parsePlatformArg(lib::synergy::ArgsBase& argsBase, const int& argc, const char* const* argv, int& i)
 {
 #if WINAPI_MSWINDOWS
-    if (isArg(i, argc, argv, NULL, "--service")) {
+    if (isArg(i, argc, argv, nullptr, "--service")) {
         LOG((CLOG_WARN "obsolete argument --service, use synergyd instead."));
         argsBase.m_shouldExit = true;
     }
-    else if (isArg(i, argc, argv, NULL, "--exit-pause")) {
+    else if (isArg(i, argc, argv, nullptr, "--exit-pause")) {
         argsBase.m_pauseOnExit = true;
     }
-    else if (isArg(i, argc, argv, NULL, "--stop-on-desk-switch")) {
+    else if (isArg(i, argc, argv, nullptr, "--stop-on-desk-switch")) {
         argsBase.m_stopOnDeskSwitch = true;
     }
     else {
@@ -163,7 +169,7 @@ ArgParser::parsePlatformArg(lib::synergy::ArgsBase& argsBase, const int& argc, c
         argsBase.m_display = argv[++i];
     }
 
-    else if (isArg(i, argc, argv, NULL, "--no-xinitthreads")) {
+    else if (isArg(i, argc, argv, nullptr, "--no-xinitthreads")) {
         argsBase.m_disableXInitThreads = true;
     }
 
@@ -184,19 +190,19 @@ ArgParser::parseToolArgs(ToolArgs& args, int argc, const char* const* argv)
 {
     // We support exactly one argument at a fix position
     static const int only_index {1};
-    if (isArg(only_index, argc, argv, NULL, "--get-active-desktop", 0)) {
+    if (isArg(only_index, argc, argv, nullptr, "--get-active-desktop", 0)) {
         args.m_printActiveDesktopName = true;
         return true;
     }
-    else if (isArg(only_index, argc, argv, NULL, "--get-installed-dir", 0)) {
+    else if (isArg(only_index, argc, argv, nullptr, "--get-installed-dir", 0)) {
         args.m_getInstalledDir = true;
         return true;
     }
-    else if (isArg(only_index, argc, argv, NULL, "--get-profile-dir", 0)) {
+    else if (isArg(only_index, argc, argv, nullptr, "--get-profile-dir", 0)) {
         args.m_getProfileDir = true;
         return true;
     }
-    else if (isArg(only_index, argc, argv, NULL, "--get-arch", 0)) {
+    else if (isArg(only_index, argc, argv, nullptr, "--get-arch", 0)) {
         args.m_getArch = true;
         return true;
     }
@@ -217,7 +223,7 @@ ArgParser::parseGenericArgs(int argc, const char* const* argv, int& i)
         // not a daemon
         argsBase().m_daemon = false;
     }
-    else if (isArg(i, argc, argv, NULL, "--daemon")) {
+    else if (isArg(i, argc, argv, nullptr, "--daemon")) {
         // daemonize
         argsBase().m_daemon = true;
     }
@@ -229,11 +235,11 @@ ArgParser::parseGenericArgs(int argc, const char* const* argv, int& i)
         // don't try to restart
         argsBase().m_restartable = false;
     }
-    else if (isArg(i, argc, argv, NULL, "--restart")) {
+    else if (isArg(i, argc, argv, nullptr, "--restart")) {
         // try to restart
         argsBase().m_restartable = true;
     }
-    else if (isArg(i, argc, argv, NULL, "--no-hooks")) {
+    else if (isArg(i, argc, argv, nullptr, "--no-hooks")) {
         argsBase().m_noHooks = true;
     }
     else if (isArg(i, argc, argv, "-h", "--help")) {
@@ -242,25 +248,25 @@ ArgParser::parseGenericArgs(int argc, const char* const* argv, int& i)
         }
         argsBase().m_shouldExit = true;
     }
-    else if (isArg(i, argc, argv, NULL, "--version")) {
+    else if (isArg(i, argc, argv, nullptr, "--version")) {
         if (m_app) {
             m_app->version();
         }
         argsBase().m_shouldExit = true;
     }
-    else if (isArg(i, argc, argv, NULL, "--no-tray")) {
+    else if (isArg(i, argc, argv, nullptr, "--no-tray")) {
         argsBase().m_disableTray = true;
     }
-    else if (isArg(i, argc, argv, NULL, "--ipc")) {
+    else if (isArg(i, argc, argv, nullptr, "--ipc")) {
         argsBase().m_enableIpc = true;
     }
-    else if (isArg(i, argc, argv, NULL, "--server")) {
+    else if (isArg(i, argc, argv, nullptr, "--server")) {
         // HACK: stop error happening when using portable (synergyp)
     }
-    else if (isArg(i, argc, argv, NULL, "--client")) {
+    else if (isArg(i, argc, argv, nullptr, "--client")) {
         // HACK: stop error happening when using portable (synergyp)
     }
-    else if (isArg(i, argc, argv, NULL, "--enable-drag-drop")) {
+    else if (isArg(i, argc, argv, nullptr, "--enable-drag-drop")) {
         bool useDragDrop = true;
 
 #ifdef WINAPI_XWINDOWS
@@ -282,18 +288,21 @@ ArgParser::parseGenericArgs(int argc, const char* const* argv, int& i)
             argsBase().m_enableDragDrop = true;
         }
     }
-    else if (isArg(i, argc, argv, NULL, "--enable-crypto")) {
+    else if (isArg(i, argc, argv, nullptr, "--enable-crypto")) {
         argsBase().m_enableCrypto = true;
     }
-    else if (isArg(i, argc, argv, NULL, "--profile-dir", 1)) {
+    else if (isArg(i, argc, argv, nullptr, "--profile-dir", 1)) {
         argsBase().m_profileDirectory = argv[++i];
     }
-    else if (isArg(i, argc, argv, NULL, "--plugin-dir", 1)) {
+    else if (isArg(i, argc, argv, nullptr, "--plugin-dir", 1)) {
         argsBase().m_pluginDirectory = argv[++i];
     }
-    else if (isArg(i, argc, argv, NULL, "--tls-cert", 1)) {
+    else if (isArg(i, argc, argv, nullptr, "--tls-cert", 1)) {
         argsBase().m_tlsCertFile = argv[++i];
     }
+    else if (isArg(i, argc, argv, nullptr, "--prevent-sleep")) {
+        argsBase().m_preventSleep = true;
+    }
     else {
         // option not supported here
         return false;
@@ -305,30 +314,20 @@ ArgParser::parseGenericArgs(int argc, const char* const* argv, int& i)
 bool
 ArgParser::parseDeprecatedArgs(int argc, const char* const* argv, int& i)
 {
-    if (isArg(i, argc, argv, NULL, "--crypto-pass")) {
-        LOG((CLOG_NOTE "--crypto-pass is deprecated"));
-        i++;
-        return true;
-    }
-    else if (isArg(i, argc, argv, NULL, "--res-w")) {
-        LOG((CLOG_NOTE "--res-w is deprecated"));
-        i++;
-        return true;
-    }
-    else if (isArg(i, argc, argv, NULL, "--res-h")) {
-        LOG((CLOG_NOTE "--res-h is deprecated"));
-        i++;
-        return true;
-    }
-    else if (isArg(i, argc, argv, NULL, "--prm-wc")) {
-        LOG((CLOG_NOTE "--prm-wc is deprecated"));
-        i++;
-        return true;
-    }
-    else if (isArg(i, argc, argv, NULL, "--prm-hc")) {
-        LOG((CLOG_NOTE "--prm-hc is deprecated"));
-        i++;
-        return true;
+    static const std::vector<const char*> deprecatedArgs = {
+        "--crypto-pass",
+        "--res-w",
+        "--res-h",
+        "--prm-wc",
+        "--prm-hc"
+    };
+
+    for (auto& arg : deprecatedArgs) {
+        if (isArg(i, argc, argv, nullptr, arg)) {
+            LOG((CLOG_NOTE "%s is deprecated", arg));
+            i++;
+            return true;
+        }
     }
 
     return false;
@@ -340,8 +339,8 @@ ArgParser::isArg(
     const char* name1, const char* name2,
     int minRequiredParameters)
 {
-    if ((name1 != NULL && strcmp(argv[argi], name1) == 0) ||
-        (name2 != NULL && strcmp(argv[argi], name2) == 0)) {
+    if ((name1 != nullptr && strcmp(argv[argi], name1) == 0) ||
+        (name2 != nullptr && strcmp(argv[argi], name2) == 0)) {
             // match.  check args left.
             if (argi + minRequiredParameters >= argc) {
                 LOG((CLOG_PRINT "%s: missing arguments for `%s'" BYE,
